==> h2gis-api-1.3.2-sources.jar: org/h2gis/api/EmptyProgressVisitor.java <==
/**
 * H2GIS is a library that brings spatial support to the H2 Database Engine
 * <http://www.h2database.com>. H2GIS is developed by CNRS
 * <http://www.cnrs.fr/>.
 *
 * This code is part of the H2GIS project. H2GIS is free software; 
 * you can redistribute it and/or modify it under the terms of the GNU
 * Lesser General Public License as published by the Free Software Foundation;
 * version 3.0 of the License.
 *
 * H2GIS is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details <http://www.gnu.org/licenses/>.
 *
 *
 * For more information, please consult: <http://www.h2gis.org/>
 * or contact directly: info_at_h2gis.org
 */

package org.h2gis.api;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;

/**
 * A progress visitor that do nothing.
 * @author Nicolas Fortin
 */
public class EmptyProgressVisitor implements ProgressVisitor {
    private boolean canceled = false;
    private PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(this);

    @Override
    public void endOfProgress() {

    }

    @Override
    public ProgressVisitor subProcess(int stepCount) {
        return this;
    }

    @Override
    public void endStep() {

    }

    @Override
    public void setStep(int idStep) {

    }

    @Override
    public int getStepCount() {
        return 0;
    }

    @Override
    public double getProgression() {
        return 0;
    }

    @Override
    public boolean isCanceled() {
        return canceled;
    }

    @Override
    public void cancel() {
        boolean oldValue = canceled;
        canceled = true;
        propertyChangeSupport.firePropertyChange(PROPERTY_CANCELED, oldValue, true);
    }

    @Override
    public void addPropertyChangeListener(String property, PropertyChangeListener listener) {
        propertyChangeSupport.addPropertyChangeListener(property, listener);
    }

    @Override
    public void removePropertyChangeListener(PropertyChangeListener listener) {
        propertyChangeSupport.removePropertyChangeListener(listener);
    }
}

==> h2gis-api-1.5.0-sources.jar: org/h2gis/api/EmptyProgressVisitor.java <==
/*
 * H2GIS is a library that brings spatial support to the H2 Database Engine
 * <http://www.h2database.com>. H2GIS is developed by CNRS
 * <http://www.cnrs.fr/>.
 *
 * This code is part of the H2GIS project. H2GIS is free software; 
 * you can redistribute it and/or modify it under the terms of the GNU
 * Lesser General Public License as published by the Free Software Foundation;
 * version 3.0 of the License.
 *
 * H2GIS is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details <http://www.gnu.org/licenses/>.
 *
 *
 * For more information, please consult: <http://www.h2gis.org/>
 * or contact directly: info_at_h2gis.org
 */

package org.h2gis.api;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;

/**
 * A progress visitor that do nothing.
 *
 * @author Nicolas Fortin
 */
public class EmptyProgressVisitor implements ProgressVisitor {

    /** Indicate if the the ProgressVisitor has been cancelled or not. */
    private boolean canceled = false;

    private PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(this);

    @Override
    public void endOfProgress() {}

    @Override
    public ProgressVisitor subProcess(int stepCount) {
        return this;
    }

    @Override
    public void endStep() {}

    @Override
    public void setStep(int idStep) { }

    @Override
    public int getStepCount() {
        return 0;
    }

    @Override
    public double getProgression() {
        return 0;
    }

    @Override
    public boolean isCanceled() {
        return canceled;
    }

    @Override
    public void cancel() {
        boolean oldValue = canceled;
        canceled = true;
        propertyChangeSupport.firePropertyChange(PROPERTY_CANCELED, oldValue, true);
    }

    @Override
    public void addPropertyChangeListener(String property, PropertyChangeListener listener) {
        propertyChangeSupport.addPropertyChangeListener(property, listener);
    }

    @Override
    public void removePropertyChangeListener(PropertyChangeListener listener) {
        propertyChangeSupport.removePropertyChangeListener(listener);
    }
}
